[Bf-blender-cvs] SVN commit: /data/svn/bf-blender [48196] branches/soc-2011-tomato: svn merge ^/trunk/blender -r48188:48195

Campbell Barton ideasman42 at gmail.com
Fri Jun 22 17:08:34 CEST 2012


Revision: 48196
          http://projects.blender.org/scm/viewvc.php?view=rev&root=bf-blender&revision=48196
Author:   campbellbarton
Date:     2012-06-22 15:08:33 +0000 (Fri, 22 Jun 2012)
Log Message:
-----------
svn merge ^/trunk/blender -r48188:48195

Revision Links:
--------------
    http://projects.blender.org/scm/viewvc.php?view=rev&root=bf-blender&revision=48188

Modified Paths:
--------------
    branches/soc-2011-tomato/source/blender/compositor/intern/COM_CompositorContext.cpp
    branches/soc-2011-tomato/source/blender/compositor/intern/COM_CompositorContext.h
    branches/soc-2011-tomato/source/blender/compositor/intern/COM_ExecutionSystem.cpp
    branches/soc-2011-tomato/source/blender/compositor/intern/COM_ExecutionSystem.h
    branches/soc-2011-tomato/source/blender/compositor/intern/COM_compositor.cpp
    branches/soc-2011-tomato/source/blender/compositor/nodes/COM_CompositorNode.cpp
    branches/soc-2011-tomato/source/blender/compositor/nodes/COM_IDMaskNode.cpp
    branches/soc-2011-tomato/source/blender/compositor/nodes/COM_LensDistortionNode.cpp
    branches/soc-2011-tomato/source/blender/compositor/nodes/COM_MaskNode.cpp
    branches/soc-2011-tomato/source/blender/compositor/nodes/COM_OutputFileNode.cpp
    branches/soc-2011-tomato/source/blender/compositor/nodes/COM_ScaleNode.cpp
    branches/soc-2011-tomato/source/blender/compositor/nodes/COM_SplitViewerNode.cpp
    branches/soc-2011-tomato/source/blender/compositor/nodes/COM_TextureNode.cpp
    branches/soc-2011-tomato/source/blender/compositor/nodes/COM_ViewerNode.cpp
    branches/soc-2011-tomato/source/blender/compositor/operations/COM_CombineChannelsOperation.cpp
    branches/soc-2011-tomato/source/blender/compositor/operations/COM_CombineChannelsOperation.h
    branches/soc-2011-tomato/source/blender/compositor/operations/COM_CompositorOperation.cpp
    branches/soc-2011-tomato/source/blender/compositor/operations/COM_CompositorOperation.h
    branches/soc-2011-tomato/source/blender/compositor/operations/COM_OutputFileOperation.cpp
    branches/soc-2011-tomato/source/blender/compositor/operations/COM_OutputFileOperation.h
    branches/soc-2011-tomato/source/blender/compositor/operations/COM_ProjectorLensDistortionOperation.cpp
    branches/soc-2011-tomato/source/blender/compositor/operations/COM_ProjectorLensDistortionOperation.h
    branches/soc-2011-tomato/source/blender/compositor/operations/COM_ReadBufferOperation.cpp
    branches/soc-2011-tomato/source/blender/compositor/operations/COM_ScreenLensDistortionOperation.cpp
    branches/soc-2011-tomato/source/blender/compositor/operations/COM_ScreenLensDistortionOperation.h
    branches/soc-2011-tomato/source/blender/compositor/operations/COM_TextureOperation.cpp
    branches/soc-2011-tomato/source/blender/compositor/operations/COM_TextureOperation.h
    branches/soc-2011-tomato/source/blender/editors/uvedit/uvedit_draw.c
    branches/soc-2011-tomato/source/blender/render/extern/include/RE_pipeline.h
    branches/soc-2011-tomato/source/blender/render/intern/source/pipeline.c

Property Changed:
----------------
    branches/soc-2011-tomato/
    branches/soc-2011-tomato/source/blender/editors/interface/interface.c
    branches/soc-2011-tomato/source/blender/editors/space_outliner/


Property changes on: branches/soc-2011-tomato
___________________________________________________________________
Modified: svn:mergeinfo
   - /branches/ge_harmony:42255,42279-42282,42286,42302,42338,42349,42616,42620,42698-42699,42739,42753,42773-42774,42832,44568,44597-44598,44793-44794
/branches/soc-2011-cucumber:37517,38166-38167,38177,38179-38180,38187,38242,38384,38387,38403-38404,38407,38968,38970,38973,39045,40845,42997-42998,43439
/branches/vgroup_modifiers:38694-39989
/trunk/blender:36831-48188
   + /branches/ge_harmony:42255,42279-42282,42286,42302,42338,42349,42616,42620,42698-42699,42739,42753,42773-42774,42832,44568,44597-44598,44793-44794
/branches/soc-2011-cucumber:37517,38166-38167,38177,38179-38180,38187,38242,38384,38387,38403-38404,38407,38968,38970,38973,39045,40845,42997-42998,43439
/branches/vgroup_modifiers:38694-39989
/trunk/blender:36831-48195

Modified: branches/soc-2011-tomato/source/blender/compositor/intern/COM_CompositorContext.cpp
===================================================================
--- branches/soc-2011-tomato/source/blender/compositor/intern/COM_CompositorContext.cpp	2012-06-22 15:06:52 UTC (rev 48195)
+++ branches/soc-2011-tomato/source/blender/compositor/intern/COM_CompositorContext.cpp	2012-06-22 15:08:33 UTC (rev 48196)
@@ -26,7 +26,7 @@
 
 CompositorContext::CompositorContext()
 {
-	this->scene = NULL;
+	this->rd = NULL;
 	this->quality = COM_QUALITY_HIGH;
 	this->hasActiveOpenCLDevices = false;
 	this->activegNode = NULL;
@@ -34,8 +34,8 @@
 
 const int CompositorContext::getFramenumber() const
 {
-	if (this->scene) {
-		return this->scene->r.cfra;
+	if (this->rd) {
+		return this->rd->cfra;
 	}
 	else {
 		return -1; /* this should never happen */
@@ -44,8 +44,8 @@
 
 const int CompositorContext::isColorManaged() const
 {
-	if (this->scene) {
-		return this->scene->r.color_mgt_flag & R_COLOR_MANAGEMENT;
+	if (this->rd) {
+		return this->rd->color_mgt_flag & R_COLOR_MANAGEMENT;
 	}
 	else {
 		return 0; /* this should never happen */

Modified: branches/soc-2011-tomato/source/blender/compositor/intern/COM_CompositorContext.h
===================================================================
--- branches/soc-2011-tomato/source/blender/compositor/intern/COM_ExecutionSystem.cpp	2012-06-22 15:06:52 UTC (rev 48195)
+++ branches/soc-2011-tomato/source/blender/compositor/intern/COM_ExecutionSystem.cpp	2012-06-22 15:08:33 UTC (rev 48196)
@@ -41,7 +41,7 @@
 
 #include "BKE_global.h"
 
-ExecutionSystem::ExecutionSystem(Scene *scene, bNodeTree *editingtree, bool rendering)
+ExecutionSystem::ExecutionSystem(RenderData *rd, bNodeTree *editingtree, bool rendering)
 {
 	context.setbNodeTree(editingtree);
 	bNode *gnode;
@@ -64,7 +64,7 @@
 
 	ExecutionSystemHelper::addbNodeTree(*this, 0, editingtree, NULL);
 
-	context.setScene(scene);
+	context.setRenderData(rd);
 	this->convertToOperations();
 	this->groupOperations(); /* group operations in ExecutionGroups */
 	unsigned int index;

Modified: branches/soc-2011-tomato/source/blender/compositor/intern/COM_ExecutionSystem.h
===================================================================
--- branches/soc-2011-tomato/source/blender/compositor/intern/COM_ExecutionSystem.h	2012-06-22 15:06:52 UTC (rev 48195)
+++ branches/soc-2011-tomato/source/blender/compositor/intern/COM_ExecutionSystem.h	2012-06-22 15:08:33 UTC (rev 48196)
@@ -156,7 +156,7 @@
 	 * @param editingtree [bNodeTree*]
 	 * @param rendering [true false]
 	 */
-	ExecutionSystem(Scene *scene, bNodeTree *editingtree, bool rendering);
+	ExecutionSystem(RenderData *rd, bNodeTree *editingtree, bool rendering);
 
 	/**
 	 * Destructor

Modified: branches/soc-2011-tomato/source/blender/compositor/intern/COM_compositor.cpp
===================================================================
--- branches/soc-2011-tomato/source/blender/compositor/intern/COM_compositor.cpp	2012-06-22 15:06:52 UTC (rev 48195)
+++ branches/soc-2011-tomato/source/blender/compositor/intern/COM_compositor.cpp	2012-06-22 15:08:33 UTC (rev 48196)
@@ -56,15 +56,9 @@
 	editingtree->progress(editingtree->prh, 0.0);
 
 	/* initialize execution system */
-	Scene *scene;
-	for (scene = (Scene*)G.main->scene.first; scene != NULL ; scene = (Scene*)scene->id.next) {
-		if (&scene->r == rd) {
-			ExecutionSystem *system = new ExecutionSystem(scene, editingtree, rendering);
-			system->execute();
-			delete system;
-			break;
-		}
-	}
+	ExecutionSystem *system = new ExecutionSystem(rd, editingtree, rendering);
+	system->execute();
+	delete system;
 
 	BLI_mutex_unlock(compositorMutex);
 }

Modified: branches/soc-2011-tomato/source/blender/compositor/nodes/COM_CompositorNode.cpp
===================================================================
--- branches/soc-2011-tomato/source/blender/compositor/nodes/COM_CompositorNode.cpp	2012-06-22 15:06:52 UTC (rev 48195)
+++ branches/soc-2011-tomato/source/blender/compositor/nodes/COM_CompositorNode.cpp	2012-06-22 15:08:33 UTC (rev 48196)
@@ -35,7 +35,7 @@
 	InputSocket *alphaSocket = this->getInputSocket(1);
 	if (imageSocket->isConnected()) {
 		CompositorOperation *colourAlphaProg = new CompositorOperation();
-		colourAlphaProg->setScene(context->getScene());
+		colourAlphaProg->setRenderData(context->getRenderData());
 		colourAlphaProg->setbNodeTree(context->getbNodeTree());
 		imageSocket->relinkConnections(colourAlphaProg->getInputSocket(0));
 		alphaSocket->relinkConnections(colourAlphaProg->getInputSocket(1));

Modified: branches/soc-2011-tomato/source/blender/compositor/nodes/COM_IDMaskNode.cpp
===================================================================
--- branches/soc-2011-tomato/source/blender/compositor/nodes/COM_IDMaskNode.cpp	2012-06-22 15:06:52 UTC (rev 48195)
+++ branches/soc-2011-tomato/source/blender/compositor/nodes/COM_IDMaskNode.cpp	2012-06-22 15:08:33 UTC (rev 48196)
@@ -38,7 +38,7 @@
 	operation->setObjectIndex(bnode->custom1);
 	
 	this->getInputSocket(0)->relinkConnections(operation->getInputSocket(0), 0, graph);
-	if (bnode->custom2 == 0 || context->getScene()->r.scemode & R_FULL_SAMPLE) {
+	if (bnode->custom2 == 0 || context->getRenderData()->scemode & R_FULL_SAMPLE) {
 		this->getOutputSocket(0)->relinkConnections(operation->getOutputSocket(0));
 	}
 	else {

Modified: branches/soc-2011-tomato/source/blender/compositor/nodes/COM_LensDistortionNode.cpp
===================================================================
--- branches/soc-2011-tomato/source/blender/compositor/nodes/COM_LensDistortionNode.cpp	2012-06-22 15:06:52 UTC (rev 48195)
+++ branches/soc-2011-tomato/source/blender/compositor/nodes/COM_LensDistortionNode.cpp	2012-06-22 15:08:33 UTC (rev 48196)
@@ -39,7 +39,7 @@
 		ProjectorLensDistortionOperation *operation = new ProjectorLensDistortionOperation();
 
 		this->getInputSocket(0)->relinkConnections(operation->getInputSocket(0), 0, graph);
-		operation->setDispertion(this->getInputSocket(2)->getStaticValues()[0]);
+		this->getInputSocket(2)->relinkConnections(operation->getInputSocket(1), 2, graph);
 		this->getOutputSocket(0)->relinkConnections(operation->getOutputSocket(0));
 
 		operation->setData(data);
@@ -50,8 +50,8 @@
 		ScreenLensDistortionOperation *operation = new ScreenLensDistortionOperation();
 
 		this->getInputSocket(0)->relinkConnections(operation->getInputSocket(0), 0, graph);
-		operation->setDistortion(this->getInputSocket(1)->getStaticValues()[0]);
-		operation->setDispertion(this->getInputSocket(2)->getStaticValues()[0]);
+		this->getInputSocket(1)->relinkConnections(operation->getInputSocket(1), 1, graph);
+		this->getInputSocket(2)->relinkConnections(operation->getInputSocket(2), 2, graph);
 		this->getOutputSocket(0)->relinkConnections(operation->getOutputSocket(0));
 
 		operation->setData(data);

Modified: branches/soc-2011-tomato/source/blender/compositor/nodes/COM_MaskNode.cpp
===================================================================
--- branches/soc-2011-tomato/source/blender/compositor/nodes/COM_MaskNode.cpp	2012-06-22 15:06:52 UTC (rev 48195)
+++ branches/soc-2011-tomato/source/blender/compositor/nodes/COM_MaskNode.cpp	2012-06-22 15:08:33 UTC (rev 48196)
@@ -36,7 +36,7 @@
 
 void MaskNode::convertToOperations(ExecutionSystem *graph, CompositorContext *context)
 {
-	const RenderData *data = &context->getScene()->r;
+	const RenderData *data = context->getRenderData();
 
 	OutputSocket *outputMask = this->getOutputSocket(0);
 

Modified: branches/soc-2011-tomato/source/blender/compositor/nodes/COM_OutputFileNode.cpp
===================================================================
--- branches/soc-2011-tomato/source/blender/compositor/nodes/COM_OutputFileNode.cpp	2012-06-22 15:06:52 UTC (rev 48195)
+++ branches/soc-2011-tomato/source/blender/compositor/nodes/COM_OutputFileNode.cpp	2012-06-22 15:08:33 UTC (rev 48196)
@@ -47,7 +47,7 @@
 	if (storage->format.imtype == R_IMF_IMTYPE_MULTILAYER) {
 		/* single output operation for the multilayer file */
 		OutputOpenExrMultiLayerOperation *outputOperation = new OutputOpenExrMultiLayerOperation(
-		        context->getScene(), context->getbNodeTree(), storage->base_path, storage->format.exr_codec);

@@ Diff output truncated at 10240 characters. @@



More information about the Bf-blender-cvs mailing list
--- branches/soc-2011-tomato/source/blender/compositor/intern/COM_CompositorContext.h	2012-06-22 15:06:52 UTC (rev 48195)
+++ branches/soc-2011-tomato/source/blender/compositor/intern/COM_CompositorContext.h	2012-06-22 15:08:33 UTC (rev 48196)
@@ -51,11 +51,11 @@
 	CompositorQuality quality;
 
 	/**
 	 * @brief Reference to the scene that is being composited.
 	 * This field is initialized in ExecutionSystem and must only be read from that point on.
 	 * @see ExecutionSystem
 	 */
-	Scene *scene;
+	RenderData *rd;
 
 	/**
 	 * @brief reference to the bNodeTree
@@ -93,7 +93,7 @@
 	/**
 	 * @brief set the scene of the context
 	 */
-	void setScene(Scene *scene) { this->scene = scene; }
+	void setRenderData(RenderData *rd) { this->rd = rd; }
 
 	/**
 	 * @brief set the bnodetree of the context
@@ -118,7 +118,7 @@
 	/**
 	 * @brief get the scene of the context
 	 */
-	const Scene *getScene() const { return this->scene; }
+	const RenderData *getRenderData() const { return this->rd; }
 
 	/**
 	 * @brief set the quality
@@ -51,11 +51,11 @@
 
 	/**
-	 * @brief Reference to the scene that is being composited.
+	 * @brief Reference to the render data that is being composited.
 	 * This field is initialized in ExecutionSystem and must only be read from that point on.
 	 * @see ExecutionSystem

Modified: branches/soc-2011-tomato/source/blender/compositor/intern/COM_ExecutionSystem.cpp
===================================================================